@@ -1,6 +1,6 @@
 import lzma
 
-from sc_compression.signatures import Signatures
+from sc_compression.signatures import Signatures, get_signature
 from sc_compression.utils.reader import Reader
 
 try:
@@ -23,7 +23,8 @@ except ImportError:
 class Decompressor(Reader):
     def __init__(self):
         super().__init__(b'')
-        self.signatures = Signatures()
+
+        self.signature = Signatures.NONE
         self.file_version = -1
         self.hash = None
 
@@ -31,11 +32,11 @@ class Decompressor(Reader):
         super().__init__(buffer, 'little')
 
         decompressed = buffer
-        signature = self.signatures.get_signature(self.buffer, self.file_version)
-        if signature == Signatures.NONE:
+        self.signature = get_signature(self.buffer, self.file_version)
+        if self.signature == Signatures.NONE:
             return decompressed
 
-        if signature == Signatures.SC:
+        if self.signature == Signatures.SC:
             super().__init__(buffer, 'big')
             self.read(2)
             self.file_version = self.readInt32()
@@ -43,10 +44,10 @@ class Decompressor(Reader):
                 self.file_version = self.readInt32()
             self.hash = self.read(self.readInt32())
             decompressed = self.decompress(buffer[self.i:])
-        elif signature == Signatures.SIG:
+        elif self.signature == Signatures.SIG:
             buffer = buffer[68:]
             decompressed = self.decompress(buffer)
-        elif signature == Signatures.SCLZ:
+        elif self.signature == Signatures.SCLZ:
             self.read(4)
             dict_size_log2 = self.readUByte()
             uncompressed_size = self.readInt32()
@@ -56,16 +57,16 @@ class Decompressor(Reader):
                     'dict_size_log2': dict_size_log2
                 }
                 decompressed = lzham.decompress(self.buffer[self.tell():], uncompressed_size, filters)
-        elif signature == Signatures.LZMA:
+        elif self.signature == Signatures.LZMA:
             decompressor = lzma.LZMADecompressor()
             compressed = self.buffer[:5] + b'\xff' * 8 + self.buffer[9:]
 
             decompressed = decompressor.decompress(compressed)
-        elif signature == Signatures.ZSTD:
+        elif self.signature == Signatures.ZSTD:
             if zstandard:
                 decompressor = zstandard.ZstdDecompressor()
                 decompressed = decompressor.decompress(self.buffer)
         else:
-            raise TypeError(signature)
+            raise TypeError(self.signature)
 
         return decompressed
